-- SpotAFault Installation Script version 1.0.0.0
-- Please make sure to read the documentation before running this script: http://docs.spotafault.com

-- This script will create the following tables:
-- 1/ spotafault_EventLog
-- Note: The script will NOT overwrite an existing table with the same name as the one being created.

-- This script will create the following stored procedures:
-- 1/ spotafault_sp_ClearEventLogItemsByIDs
-- 2/ spotafault_sp_DeleteItemFromEventLog
-- 3/ spotafault_sp_InsertEventToLog
-- 4/ spotafault_sp_SelectFromEventLog
-- 5/ spotafault_sp_SelectSingleDataFromEventLog
-- Not: If a stored procedure with the same name as the one being created already exists, it will be dropped and re-created.

-- ---------------------------------------------------------------------------
-- tables start
-- ---------------------------------------------------------------------------
-- ---------------------------------------------------------------------------
-- create spotafault_EventLog
-- ---------------------------------------------------------------------------

DECLARE @blLogExists bit
SET @blLogExists = 0
IF EXISTS (SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'spotafault_EventLog')
SET @blLogExists = 1
IF @blLogExists = 0
CREATE TABLE [dbo].[spotafault_EventLog](
	[ID] [int] IDENTITY(1,1) NOT NULL,
	[ApplicationName] [nvarchar](256) NOT NULL,
	[EventCode] [int] NOT NULL,
	[EventDetailCode] [int] NOT NULL,
	[EventID] [char](36) NOT NULL,
	[EventTime] [datetime] NOT NULL,
	[EventType] [int] NOT NULL,
	[EventMessage] [nvarchar](2048) NOT NULL,
	[CompleteEventData] [varbinary](max) NULL,
 CONSTRAINT [PK_spotafault_EventLog] PRIMARY KEY NONCLUSTERED 
([ID] ASC) WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]

-- ---------------------------------------------------------------------------
-- tables  end
-- ---------------------------------------------------------------------------
 
-- ---------------------------------------------------------------------------
-- contraints start
-- ---------------------------------------------------------------------------

IF @blLogExists = 0
BEGIN
ALTER TABLE [dbo].[spotafault_EventLog] ADD  CONSTRAINT [DF_spotafault_EventLog_ApplicationName]  DEFAULT ('') FOR [ApplicationName]
ALTER TABLE [dbo].[spotafault_EventLog] ADD  CONSTRAINT [DF_spotafault_EventLog_EventCode]  DEFAULT ((0)) FOR [EventCode]
ALTER TABLE [dbo].[spotafault_EventLog] ADD  CONSTRAINT [DF_spotafault_EventLog_EventDetailCode]  DEFAULT ((0)) FOR [EventDetailCode]
ALTER TABLE [dbo].[spotafault_EventLog] ADD  CONSTRAINT [DF_spotafault_EventLog_EventID]  DEFAULT ('') FOR [EventID]
ALTER TABLE [dbo].[spotafault_EventLog] ADD  CONSTRAINT [DF_spotafault_EventLog_EventTime]  DEFAULT (getdate()) FOR [EventTime]
ALTER TABLE [dbo].[spotafault_EventLog] ADD  CONSTRAINT [DF_spotafault_EventLog_EventType]  DEFAULT ((1)) FOR [EventType]
ALTER TABLE [dbo].[spotafault_EventLog] ADD  CONSTRAINT [DF_spotafault_EventLog_EventMessage]  DEFAULT ('') FOR [EventMessage]
END
GO

-- ----------------------------------------------------------------
-- contraints end
-- ----------------------------------------------------------------

-- ----------------------------------------------------------------
-- stored procedures start
-- ----------------------------------------------------------------

-- ----------------------------------------------------------------
--create spotafault_sp_ClearEventLogItemsByIDs
-- ----------------------------------------------------------------

IF EXISTS (SELECT ROUTINE_NAME FROM INFORMATION_SCHEMA.ROUTINES WHERE ROUTINE_NAME='spotafault_sp_ClearEventLogItemsByIDs') 
DROP PROCEDURE spotafault_sp_ClearEventLogItemsByIDs

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[spotafault_sp_ClearEventLogItemsByIDs] (
@strEventIDs varchar(MAX),
@intDeleted int output
)
AS

SET NOCOUNT ON

-- Deletes all matching records from the spotafault_EventLog table
DELETE FROM spotafault_EventLog WHERE @strEventIDs LIKE '%' + EventID + '%'

SET @intDeleted = @@ROWCOUNT

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

-- ----------------------------------------------------------------
-- create spotafault_sp_InsertEventToLog
-- ----------------------------------------------------------------

IF EXISTS (SELECT ROUTINE_NAME FROM INFORMATION_SCHEMA.ROUTINES WHERE ROUTINE_NAME='spotafault_sp_InsertEventToLog') 
DROP PROCEDURE spotafault_sp_InsertEventToLog

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE Procedure [dbo].[spotafault_sp_InsertEventToLog] (
@strApplicationName  nvarchar(256),
@intEventDetailCode  int,
@intEventCode  int,
@strEventID  char(36),
@strEventMessage  nvarchar(1024),
@dtEventTime  datetime,
@intEventType int,
@binCompleteEventData varbinary(max),
@intMaxSize int,
@intID int output
) AS

SET NOCOUNT ON 

-- Inserts a record into the spotafault_EventLog table
INSERT INTO spotafault_EventLog (ApplicationName, EventCode, EventDetailCode, EventID, EventMessage, EventTime, EventType, CompleteEventData)
VALUES (@strApplicationName, @intEventCode, @intEventDetailCode, @strEventID, @strEventMessage, @dtEventTime, @intEventType, @binCompleteEventData)

-- Get new Event identity -
SET @intID = @@IDENTITY

-- Delete old records if necessary
DECLARE @intCurrentSize int
SET @intCurrentSize = (SELECT COUNT(ID) FROM spotafault_EventLog)
IF @intCurrentSize>@intMaxSize
DELETE TOP(@intCurrentSize - @intMaxSize) FROM spotafault_EventLog

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

-- ----------------------------------------------------------------
-- create spotafault_sp_SelectFromEventLog
-- ----------------------------------------------------------------

IF EXISTS (SELECT ROUTINE_NAME FROM INFORMATION_SCHEMA.ROUTINES WHERE ROUTINE_NAME='spotafault_sp_SelectFromEventLog') 
DROP PROCEDURE spotafault_sp_SelectFromEventLog

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE Procedure [dbo].[spotafault_sp_SelectFromEventLog] (
@dtStartDate datetime,
@dtEndDate datetime
) AS

SET NOCOUNT ON 

--  Selects matching records from the spotafault_EventLog table
SELECT ApplicationName, EventCode, EventDetailCode, EventID, EventMessage, EventTime, EventType FROM spotafault_EventLog WHERE EventTime>=@dtStartDate AND EventTime<=@dtEndDate ORDER BY EventTime DESC

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

-- ----------------------------------------------------------------
-- create spotafault_sp_SelectSingleDataFromEventLog
-- ----------------------------------------------------------------
IF EXISTS (SELECT ROUTINE_NAME FROM INFORMATION_SCHEMA.ROUTINES WHERE ROUTINE_NAME='spotafault_sp_SelectSingleDataFromEventLog') 
DROP PROCEDURE spotafault_sp_SelectSingleDataFromEventLog

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE Procedure [dbo].[spotafault_sp_SelectSingleDataFromEventLog] (
@strEventID  char(36)
) AS

SET NOCOUNT ON 

--  Selects xml data for a single record from the spotafault_EventLog table
SELECT CompleteEventData FROM spotafault_EventLog WHERE EventID = @strEventID

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

-- ----------------------------------------------------------------
-- stored procedures end
-- ----------------------------------------------------------------